@@ -275,6 +275,96 @@ def bandpass_filter(
     return signal
 
 
+def bandpass_filter_ideal(
+    signal: np.ndarray,
+    fs: Union[int, float],
+    l_cutoff: Union[int, float],
+    h_cutoff: Union[int, float],
+) -> np.ndarray:
+    """
+    .. warning:: This method **may cause distortion of signal**. \
+        Generally, this operates well on signals extracted in low resolution. \
+        In order to check the distortion of signals, \
+        it is recommended to monitor the linear transition of phase.
+
+    1D ideal bandpass filter.
+
+    Parameters
+    ----------
+    signal : numpy.ndarray
+        Original time-domain signal.
+    fs : Union[int, float]
+        Sampling rate.
+    l_cutoff : Union[int, float]
+        Low cutoff frequency.
+    h_cutoff : Union[int, float]
+        High cutoff frequency.
+
+    Returns
+    -------
+    out : numpy.ndarray
+        Filtered signal.
+        Input shape is [signal_length,] and output shape is [signal_length,].
+
+    Examples
+    --------
+    Apply the filter to 1d signal. And then check the frequency component of the filtered signal.
+
+    >>> fs = 5000.0
+    >>> t = np.linspace(0, 1, int(fs))
+    >>> signal = 10.0 * np.sin(2 * np.pi * 20.0 * t)
+    >>> signal += 5.0 * np.sin(2 * np.pi * 100.0 * t)
+    >>> signal += 5.0 * np.sin(2 * np.pi * 500.0 * t)
+    >>> signal.shape
+    (5000,)
+    >>> freq_x = np.fft.rfftfreq(signal.size, 1 / fs)[:-1]
+    >>> origin_fft_mag = abs((np.fft.rfft(signal) / signal.size)[:-1] * 2)
+    >>> origin_freq = freq_x[np.where(origin_fft_mag > 0.5)]
+    >>> origin_freq
+    [ 20., 100., 500.]
+    >>> filtered_signal = bandpass_filter_ideal(signal, fs, l_cutoff=50, h_cutoff=300)
+    >>> filtered_fft_mag = abs((np.fft.rfft(filtered_signal) / signal.size)[:-1] * 2)
+    >>> filtered_freq = freq_x[np.where(filtered_fft_mag > 0.5)]
+    >>> filtered_freq
+    [ 100.]
+    """
+    if not (isinstance(fs, int) | isinstance(fs, float)):
+        raise TypeError(f"Argument 'fs' must be of type int or float, not {type(fs).__name__}")
+    if not (isinstance(l_cutoff, int) | isinstance(l_cutoff, float)):
+        raise TypeError(
+            f"Argument 'l_cutoff' must be of type int or float, not {type(l_cutoff).__name__}"
+        )
+    if not (isinstance(h_cutoff, int) | isinstance(h_cutoff, float)):
+        raise TypeError(
+            f"Argument 'h_cutoff' must be of type int or float, not {type(h_cutoff).__name__}"
+        )
+    if len(signal.shape) > 1:
+        raise TypeError(f"Argument 'len(signal.shape)' must be 1, not {len(signal.shape)}")
+
+    n = len(signal)
+    t = n / fs
+    k = np.arange(n)
+
+    freq_full = k / t
+
+    yfull = np.fft.fft(signal)
+    band2low = fs - h_cutoff
+    band2high = fs - l_cutoff
+    band1low_idx = np.where(freq_full >= l_cutoff)[0][0]
+    band1high_idx = np.where(freq_full >= h_cutoff)[0][0]
+    band2low_idx = np.where(freq_full >= band2low)[0][0]
+    band2high_idx = np.where(freq_full >= band2high)[0][0]
+    band1_idx = np.arange(band1low_idx, band1high_idx)
+    band2_idx = np.arange(band2low_idx, band2high_idx)
+    band_idx = np.vstack([band1_idx, band2_idx]).T
+    full_idx = np.arange(n)
+    notch_idx = np.setdiff1d(full_idx, band_idx)
+    filt_yfull = yfull.copy()
+    filt_yfull[notch_idx] = 0
+    filter_signal = np.real(np.fft.ifft(filt_yfull))
+    return filter_signal
+
+
 def bandstop_filter(
     signal: np.ndarray,
     fs: Union[int, float],
